@@ -101,7 +101,7 @@ static void enc_preprocess(MSFilter *f){
 	params.i_fps_num=(int)d->fps;
 	params.i_fps_den=1;
 	params.i_slice_max_size=ms_get_payload_max_size()-100; /*-100 security margin*/
-	/*params.i_level_idc=30;*/
+	params.i_level_idc=13;
 	
 	params.rc.i_rc_method = X264_RC_ABR;
 	params.rc.i_bitrate=(int)( ( ((float)d->bitrate)*0.8)/1000.0);
@@ -585,4 +585,5 @@ static MSFilterDesc h264_dec_desc={
 void libmsx264_init(void){
 	ms_filter_register(&x264_enc_desc);
 	ms_filter_register(&h264_dec_desc);
+	ms_message("ms264-" VERSION " plugin registered.");
 }
